@@ -1,6 +1,7 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-from builtins import range
+from builtins import range, str
+from future.utils import PY2
 from typing import TYPE_CHECKING
 
 from .exceptions import assert_choice
@@ -8,6 +9,9 @@ from .exceptions import assert_choice
 if TYPE_CHECKING:
 	from typing import Iterable, Iterator
 
+if PY2:
+	bytes = bytearray
+
 def encode_binary(boolit, pad="0"):
 	# type: (Union[str, Iterator[bool]], str) -> bytes
 
