@@ -15,12 +15,12 @@ from .iter import progress
 from .object import cast
 
 if TYPE_CHECKING:
-	from typing import Any, Dict, Iterable, List, Tuple, MutableMapping, Iterator
+	from typing import Any, Dict, Iterable, List, Tuple, MutableMapping, Iterator, Union
 
 	RawDocument = List[int]
 	IterableDocuments = Iterable[Iterable[int]]
 	TopicsMapping = MutableMapping[Tuple[int, int], int]
-	# fixme: where are Indices ?
+	Indices = Union[slice, np.ndarray]
 
 def top_topics(id2word, term_topic_matrix, num_words=10, decimals=2):
 	# type: (Dict[int, str], float[K, V], int) -> Iterator[List[Tuple[str, float]]]
@@ -91,9 +91,14 @@ class LDABase(object):
 		self.nk[k] -= 1
 
 	def _validate(self, M, K, V):
-		assert M > 0, "Number of documents must be larger than zero"
-		assert K > 0, "Number of topics must be larger than zero"
-		assert V > 0, "Vocabulary size must be larger than zero"
+		# type: (int, int, int) -> None
+
+		if M <= 0:
+			raise ValueError("Number of documents must be larger than zero")
+		if K <= 0:
+			raise ValueError("Number of topics must be larger than zero")
+		if V <= 0:
+			raise ValueError("Vocabulary size must be larger than zero")
 
 		assert self.nmk.shape == (M, K)
 		assert self.nm.shape == (M, )
