@@ -23,12 +23,28 @@ def not_in(s):
 
 	return lambda x: x not in s
 
+def operator_in(s):
+	# type: (Container[T], ) -> Callable[[T], bool]
+
+	""" Comparable to stdlib `operator.itemgetter` type functions.
+		It returns a function which will return a boolean indicating if
+		its argument if in `s`. `s` should be a set-like for better performance.
+	"""
+
+	return lambda x: x in s
+
 def logical_xor(a, b):
 	# type: (Any, Any) -> bool
 	# this is just the != operator for bools
 
 	return not (a and b) and (a or b)
 
+def logical_xnor(a, b):
+	# type: (Any, Any) -> bool
+	# this is just the == operator for bools
+
+	return not (a or b) or (a and b)
+
 def logical_implication(a, b):
 	# type: (Any, Any) -> bool
 
@@ -36,6 +52,13 @@ def logical_implication(a, b):
 
 	return (not a) or b
 
+def logical_nonimplication(a, b):
+	# type: (Any, Any) -> bool
+
+	""" if a is True, b must be False """
+
+	return a and (not b)
+
 def converse_implication(a, b):
 	# type: (Any, Any) -> bool
 
